Exception: Segmentor::Errors::SessionStateError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/segmentor/errors/session_error.rb

Overview

SessionStateError is raised when the session status is not valid or the change requested for the status is invalid